@@ -83,8 +83,6 @@ class Domoticz(IPlugin):
 				log.msg("BODIES  :  %s" % (bodies))
 				log.msg("local  :  %s" % (local))
 				log.msg("number  :  %s" % (int(rs['idx'])))
-#periph action
-##http://192.168.0.1:8080/json.htm?type=command&param=switchlight&idx=39&switchcmd=On&level=0
 #Panel security
 ##http://192.168.0.1:8080/json.htm?type=command&param=setsecstatus&secstatus=0&seccode=1234
 #Sensor action
@@ -101,14 +99,14 @@ class Domoticz(IPlugin):
 #				log.msg("*********************************************  : ")
 #				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
 				for rt in jsonreq['result'] :
-					log.msg("*** jsonreq - NT-rt - idx   :  %s" % (rt['idx']))
-					log.msg("*** jsonreq - NT-rs - idx   :  %s" % (rs['idx']))
+#					log.msg("*** jsonreq - NT-rt - idx   :  %s" % (rt['idx']))
+#					log.msg("*** jsonreq - NT-rs - idx   :  %s" % (rs['idx']))
 
 					if int(rs['idx']) == int(rt['idx']):
 						log.msg("**************************  jsonreq - idx   :  %s" % (rt['idx']))
 						log.msg("*********  jsonreq - batlevel   :  %s" % (rt['BatteryLevel']))
 						log.msg("*********  jsonreq - Temp   :  %s" % (rt['Temp']))
-						log.msg("*********  jsonreq - Name   :  %s" % (rt['Name']))
+#						log.msg("*********  jsonreq - Name   :  %s" % (rt['Name']))
 						log.msg("*********  jsonreq - Data   :  %s" % (rt['Data']))
 						if local == "temperature" :
 							bodies = "la temperature a été trouvée"
